@@ -26,13 +26,12 @@
 #include <QtCore/QIODevice>
 #include <QtCore/QFileInfo>
 #include <QtCore/QFile>
+#include <QtCore/QDir>
 
 // KDE
-#include <KStandardDirs>
-#include <KGlobal>
 #include <KConfig>
 #include <KLocalizedString>
-#include <KDebug>
+#include <QDebug>
 
 using namespace Konsole;
 
@@ -93,12 +92,12 @@ ColorScheme* KDE3ColorSchemeReader::read()
 
         if (line.startsWith(QLatin1String("color"))) {
             if (!readColorLine(line, scheme))
-                kWarning() << "Failed to read KDE 3 color scheme line" << line;
+                qWarning() << "Failed to read KDE 3 color scheme line" << line;
         } else if (line.startsWith(QLatin1String("title"))) {
             if (!readTitleLine(line, scheme))
-                kWarning() << "Failed to read KDE 3 color scheme title line" << line;
+                qWarning() << "Failed to read KDE 3 color scheme title line" << line;
         } else {
-            kWarning() << "KDE 3 color scheme contains an unsupported feature, '" <<
+            qWarning() << "KDE 3 color scheme contains an unsupported feature, '" <<
                        line << "'";
         }
     }
@@ -149,17 +148,13 @@ bool KDE3ColorSchemeReader::readTitleLine(const QString& line, ColorScheme* sche
 
     QString description = line.mid(spacePos + 1);
 
-    scheme->setDescription(i18n(description.toUtf8()));
+    scheme->setDescription(i18n(description.toUtf8().constData()));
     return true;
 }
 
 ColorSchemeManager::ColorSchemeManager()
     : _haveLoadedAll(false)
 {
-#if defined(Q_WS_X11)
-    // Allow looking up colors in the X11 color database
-    QColor::setAllowX11ColorNames(true);
-#endif
 }
 
 ColorSchemeManager::~ColorSchemeManager()
@@ -167,7 +162,7 @@ ColorSchemeManager::~ColorSchemeManager()
     qDeleteAll(_colorSchemes);
 }
 
-K_GLOBAL_STATIC(ColorSchemeManager , theColorSchemeManager)
+Q_GLOBAL_STATIC(ColorSchemeManager, theColorSchemeManager)
 
 ColorSchemeManager* ColorSchemeManager::instance()
 {
@@ -196,7 +191,7 @@ void ColorSchemeManager::loadAllColorSchemes()
     }
 
     if (failed > 0)
-        kWarning() << "failed to load " << failed << " color schemes.";
+        qWarning() << "failed to load " << failed << " color schemes.";
 
     _haveLoadedAll = true;
 }
@@ -223,7 +218,7 @@ bool ColorSchemeManager::loadColorScheme(const QString& filePath)
     scheme->read(config);
 
     if (scheme->name().isEmpty()) {
-        kWarning() << "Color scheme in" << filePath << "does not have a valid name and was not loaded.";
+        qWarning() << "Color scheme in" << filePath << "does not have a valid name and was not loaded.";
         delete scheme;
         return false;
     }
@@ -231,7 +226,7 @@ bool ColorSchemeManager::loadColorScheme(const QString& filePath)
     if (!_colorSchemes.contains(info.baseName())) {
         _colorSchemes.insert(scheme->name(), scheme);
     } else {
-        kDebug() << "color scheme with name" << scheme->name() << "has already been" <<
+        //qDebug() << "color scheme with name" << scheme->name() << "has already been" <<
                  "found, ignoring.";
 
         delete scheme;
@@ -252,7 +247,7 @@ bool ColorSchemeManager::loadKDE3ColorScheme(const QString& filePath)
     file.close();
 
     if (scheme->name().isEmpty()) {
-        kWarning() << "color scheme name is not valid.";
+        qWarning() << "color scheme name is not valid.";
         delete scheme;
         return false;
     }
@@ -262,7 +257,7 @@ bool ColorSchemeManager::loadKDE3ColorScheme(const QString& filePath)
     if (!_colorSchemes.contains(info.baseName())) {
         addColorScheme(scheme);
     } else {
-        kWarning() << "color scheme with name" << scheme->name() << "has already been" <<
+        qWarning() << "color scheme with name" << scheme->name() << "has already been" <<
                    "found, ignoring.";
         delete scheme;
     }
@@ -272,16 +267,28 @@ bool ColorSchemeManager::loadKDE3ColorScheme(const QString& filePath)
 
 QStringList ColorSchemeManager::listColorSchemes()
 {
-    return KGlobal::dirs()->findAllResources("data",
-            "konsole/*.colorscheme",
-            KStandardDirs::NoDuplicates);
+    QStringList colorschemes;
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "konsole", QStandardPaths::LocateDirectory);
+    Q_FOREACH (const QString& dir, dirs) {
+        const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.colorscheme"));
+        Q_FOREACH (const QString& file, fileNames) {
+            colorschemes.append(dir + '/' + file);
+        }
+    }
+    return colorschemes;
 }
 
 QStringList ColorSchemeManager::listKDE3ColorSchemes()
 {
-    return KGlobal::dirs()->findAllResources("data",
-            "konsole/*.schema",
-            KStandardDirs::NoDuplicates);
+    QStringList kde3colorschemes;
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "konsole", QStandardPaths::LocateDirectory);
+    Q_FOREACH (const QString& dir, dirs) {
+        const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.schema"));
+        Q_FOREACH (const QString& file, fileNames) {
+            kde3colorschemes.append(dir + '/' + file);
+        }
+    }
+    return kde3colorschemes;
 }
 
 const ColorScheme ColorSchemeManager::_defaultColorScheme;
@@ -301,7 +308,10 @@ void ColorSchemeManager::addColorScheme(ColorScheme* scheme)
     _colorSchemes.insert(scheme->name(), scheme);
 
     // save changes to disk
-    QString path = KGlobal::dirs()->saveLocation("data", "konsole/") + scheme->name() + ".colorscheme";
+
+    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/konsole/");
+    QDir().mkpath(dir);
+    const QString path = dir + scheme->name() + QStringLiteral(".colorscheme");
     KConfig config(path , KConfig::NoGlobals);
 
     scheme->write(config);
@@ -318,7 +328,7 @@ bool ColorSchemeManager::deleteColorScheme(const QString& name)
         _colorSchemes.remove(name);
         return true;
     } else {
-        kWarning() << "Failed to remove color scheme -" << path;
+        qWarning() << "Failed to remove color scheme -" << path;
         return false;
     }
 }
@@ -332,7 +342,7 @@ const ColorScheme* ColorSchemeManager::findColorScheme(const QString& name)
     // Konsole will create a sub-folder in that case (bko 315086)
     // More code will have to go in to prevent the users from doing that.
     if (name.contains("/")) {
-        kWarning() << name << " has an invalid character / in the name ... skipping";
+        qWarning() << name << " has an invalid character / in the name ... skipping";
         return defaultColorScheme();
     }
 
@@ -348,7 +358,7 @@ const ColorScheme* ColorSchemeManager::findColorScheme(const QString& name)
                 return findColorScheme(name);
         }
 
-        kWarning() << "Could not find color scheme - " << name;
+        qWarning() << "Could not find color scheme - " << name;
 
         return 0;
     }
@@ -356,13 +366,12 @@ const ColorScheme* ColorSchemeManager::findColorScheme(const QString& name)
 
 QString ColorSchemeManager::findColorSchemePath(const QString& name) const
 {
-    QString path = KStandardDirs::locate("data", "konsole/" + name + ".colorscheme");
+    QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".colorscheme"));
 
-    if (!path.isEmpty())
+    if (!path.isEmpty()) {
         return path;
+    }
 
-    path = KStandardDirs::locate("data", "konsole/" + name + ".schema");
-
-    return path;
+    return QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".schema"));
 }
 
