@@ -30,9 +30,8 @@
 
 // KDE
 #include <KColorScheme>
-#include <KLineEdit>
+#include <QLineEdit>
 #include <KLocalizedString>
-#include <KIcon>
 
 using namespace Konsole;
 
@@ -53,12 +52,12 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget* aParent)
     closeButton->setObjectName(QLatin1String("close-button"));
     closeButton->setToolTip(i18nc("@info:tooltip", "Close the search bar"));
     closeButton->setAutoRaise(true);
-    closeButton->setIcon(KIcon("dialog-close"));
-    connect(closeButton , SIGNAL(clicked()) , this , SIGNAL(closeClicked()));
+    closeButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
+    connect(closeButton , &QToolButton::clicked , this , &Konsole::IncrementalSearchBar::closeClicked);
 
     QLabel* findLabel = new QLabel(i18nc("@label:textbox", "Find:"), this);
-    _searchEdit = new KLineEdit(this);
-    _searchEdit->setClearButtonShown(true);
+    _searchEdit = new QLineEdit(this);
+    _searchEdit->setClearButtonEnabled(true);
     _searchEdit->installEventFilter(this);
     _searchEdit->setObjectName(QLatin1String("search-edit"));
     _searchEdit->setToolTip(i18nc("@info:tooltip", "Enter the text to search for here"));
@@ -74,28 +73,27 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget* aParent)
     _searchTimer = new QTimer(this);
     _searchTimer->setInterval(250);
     _searchTimer->setSingleShot(true);
-    connect(_searchTimer , SIGNAL(timeout()) , this , SLOT(notifySearchChanged()));
-    connect(_searchEdit , SIGNAL(clearButtonClicked()) , this , SLOT(clearLineEdit()));
-    connect(_searchEdit , SIGNAL(textChanged(QString)) , _searchTimer , SLOT(start()));
+    connect(_searchTimer , &QTimer::timeout , this , &Konsole::IncrementalSearchBar::notifySearchChanged);
+    connect(_searchEdit , &QLineEdit::textChanged , _searchTimer , static_cast<void(QTimer::*)()>(&QTimer::start));
 
     _findNextButton = new QToolButton(this);
     _findNextButton->setObjectName(QLatin1String("find-next-button"));
     _findNextButton->setText(i18nc("@action:button Go to the next phrase", "Next"));
     _findNextButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     _findNextButton->setToolTip(i18nc("@info:tooltip", "Find the next match for the current search phrase"));
-    connect(_findNextButton , SIGNAL(clicked()) , this , SIGNAL(findNextClicked()));
+    connect(_findNextButton , &QToolButton::clicked , this , &Konsole::IncrementalSearchBar::findNextClicked);
 
     _findPreviousButton = new QToolButton(this);
     _findPreviousButton->setObjectName(QLatin1String("find-previous-button"));
     _findPreviousButton->setText(i18nc("@action:button Go to the previous phrase", "Previous"));
     _findPreviousButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     _findPreviousButton->setToolTip(i18nc("@info:tooltip", "Find the previous match for the current search phrase"));
-    connect(_findPreviousButton , SIGNAL(clicked()) , this , SIGNAL(findPreviousClicked()));
+    connect(_findPreviousButton , &QToolButton::clicked , this , &Konsole::IncrementalSearchBar::findPreviousClicked);
 
 
     _searchFromButton = new QToolButton(this);
     _searchFromButton->setObjectName(QLatin1String("search-from-button"));
-    connect(_searchFromButton , SIGNAL(clicked()) , this , SIGNAL(searchFromClicked()));
+    connect(_searchFromButton , &QToolButton::clicked , this , &Konsole::IncrementalSearchBar::searchFromClicked);
 
     QToolButton* optionsButton = new QToolButton(this);
     optionsButton->setObjectName(QLatin1String("find-options-button"));
@@ -121,27 +119,23 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget* aParent)
     _caseSensitive = optionsMenu->addAction(i18nc("@item:inmenu", "Case sensitive"));
     _caseSensitive->setCheckable(true);
     _caseSensitive->setToolTip(i18nc("@info:tooltip", "Sets whether the search is case sensitive"));
-    connect(_caseSensitive, SIGNAL(toggled(bool)),
-            this, SIGNAL(matchCaseToggled(bool)));
+    connect(_caseSensitive, &QAction::toggled, this, &Konsole::IncrementalSearchBar::matchCaseToggled);
 
     _regExpression = optionsMenu->addAction(i18nc("@item:inmenu", "Match regular expression"));
     _regExpression->setCheckable(true);
-    connect(_regExpression, SIGNAL(toggled(bool)),
-            this, SIGNAL(matchRegExpToggled(bool)));
+    connect(_regExpression, &QAction::toggled, this, &Konsole::IncrementalSearchBar::matchRegExpToggled);
 
     _highlightMatches = optionsMenu->addAction(i18nc("@item:inmenu", "Highlight all matches"));
     _highlightMatches->setCheckable(true);
     _highlightMatches->setToolTip(i18nc("@info:tooltip", "Sets whether matching text should be highlighted"));
     _highlightMatches->setChecked(true);
-    connect(_highlightMatches, SIGNAL(toggled(bool)),
-            this, SIGNAL(highlightMatchesToggled(bool)));
+    connect(_highlightMatches, &QAction::toggled, this, &Konsole::IncrementalSearchBar::highlightMatchesToggled);
 
     _reverseSearch = optionsMenu->addAction(i18n("Search backwards"));
     _reverseSearch->setCheckable(true);
     _reverseSearch->setToolTip(i18n("Sets whether search should start from the bottom"));
     _reverseSearch->setChecked(true);
-    connect(_reverseSearch, SIGNAL(toggled(bool)),
-            this, SLOT(updateButtonsAccordingToReverseSearchSetting()));
+    connect(_reverseSearch, &QAction::toggled, this, &Konsole::IncrementalSearchBar::updateButtonsAccordingToReverseSearchSetting);
     updateButtonsAccordingToReverseSearchSetting();
 
     barLayout->addStretch();
@@ -162,13 +156,13 @@ void IncrementalSearchBar::updateButtonsAccordingToReverseSearchSetting()
     if (_reverseSearch->isChecked()) {
         _searchFromButton->setText(i18nc("@action:button Search from bottom", "From bottom"));
         _searchFromButton->setToolTip(i18n("Search for the current search phrase from the bottom"));
-        _findNextButton->setIcon(KIcon("go-up-search"));
-        _findPreviousButton->setIcon(KIcon("go-down-search"));
+        _findNextButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up-search")));
+        _findPreviousButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down-search")));
     } else {
         _searchFromButton->setText(i18nc("@action:button Search from top", "From top"));
         _searchFromButton->setToolTip(i18n("Search for the current search phrase from the top"));
-        _findNextButton->setIcon(KIcon("go-down-search"));
-        _findPreviousButton->setIcon(KIcon("go-up-search"));
+        _findNextButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down-search")));
+        _findPreviousButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up-search")));
     }
 }
 
@@ -283,4 +277,3 @@ const QBitArray IncrementalSearchBar::optionsChecked()
     return options;
 }
 
-#include "IncrementalSearchBar.moc"
