@@ -30,9 +30,10 @@
 #include <KActionMenu>
 #include <KCmdLineArgs>
 #include <KShortcutsDialog>
-#include <KLocale>
-#include <KMenu>
-#include <KMenuBar>
+#include <KLocalizedString>
+
+#include <QMenu>
+#include <QMenuBar>
 #include <KMessageBox>
 #include <KToggleFullScreenAction>
 #include <KStandardAction>
@@ -42,6 +43,9 @@
 #include <KNotifyConfigWidget>
 #include <KConfigDialog>
 #include <KApplication>
+#include <KGlobal>
+#include <KShortcut>
+#include <KIconLoader>
 
 // Konsole
 #include "BookmarkHandler.h"
@@ -53,23 +57,12 @@
 #include "SessionManager.h"
 #include "ProfileManager.h"
 #include "KonsoleSettings.h"
+#include "WindowSystemInfo.h"
 #include "settings/GeneralSettings.h"
 #include "settings/TabBarSettings.h"
 
 using namespace Konsole;
 
-/* Normally it would be enough to just have this determined via the window
-   manager. But there exist GPU drivers (NVIDIA) that have serious performance
-   issues if transparency is enabled inside Konsole. The rest of the system
-   works fine. NVIDIA users might want to use --notransparency to work
-   around such issues. */
-static bool useTransparency()
-{
-    const KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
-    const bool compositingAvailable = KWindowSystem::compositingActive();
-    return compositingAvailable && args->isSet("transparency");
-}
-
 MainWindow::MainWindow()
     : KXmlGuiWindow()
     , _bookmarkHandler(0)
@@ -94,34 +87,24 @@ MainWindow::MainWindow()
         }
     }
 
-    if (useTransparency()) {
-        // It is useful to have translucent terminal area
-        setAttribute(Qt::WA_TranslucentBackground, true);
-        // But it is mostly annoying to have translucent menubar and tabbar
-        setAttribute(Qt::WA_NoSystemBackground, false);
-    }
+    connect(KWindowSystem::self(), &KWindowSystem::compositingChanged, this, &MainWindow::updateUseTransparency);
+
+    updateUseTransparency();
 
     // create actions for menus
     setupActions();
 
     // create view manager
     _viewManager = new ViewManager(this, actionCollection());
-    connect(_viewManager, SIGNAL(empty()), this, SLOT(close()));
-    connect(_viewManager, SIGNAL(activeViewChanged(SessionController*)), this,
-            SLOT(activeViewChanged(SessionController*)));
-    connect(_viewManager, SIGNAL(unplugController(SessionController*)), this,
-            SLOT(disconnectController(SessionController*)));
-    connect(_viewManager, SIGNAL(viewPropertiesChanged(QList<ViewProperties*>)),
-            bookmarkHandler(), SLOT(setViews(QList<ViewProperties*>)));
+    connect(_viewManager, &Konsole::ViewManager::empty, this, &Konsole::MainWindow::close);
+    connect(_viewManager, &Konsole::ViewManager::activeViewChanged, this, &Konsole::MainWindow::activeViewChanged);
+    connect(_viewManager, &Konsole::ViewManager::unplugController, this, &Konsole::MainWindow::disconnectController);
+    connect(_viewManager, &Konsole::ViewManager::viewPropertiesChanged, bookmarkHandler(), &Konsole::BookmarkHandler::setViews);
 
-    connect(_viewManager, SIGNAL(updateWindowIcon()), this,
-            SLOT(updateWindowIcon()));
-    connect(_viewManager, SIGNAL(newViewRequest(Profile::Ptr)),
-            this, SLOT(newFromProfile(Profile::Ptr)));
-    connect(_viewManager, SIGNAL(newViewRequest()),
-            this, SLOT(newTab()));
-    connect(_viewManager, SIGNAL(viewDetached(Session*)),
-            this, SIGNAL(viewDetached(Session*)));
+    connect(_viewManager, &Konsole::ViewManager::updateWindowIcon, this, &Konsole::MainWindow::updateWindowIcon);
+    connect(_viewManager, static_cast<void(ViewManager::*)(Profile::Ptr)>(&Konsole::ViewManager::newViewRequest), this, &Konsole::MainWindow::newFromProfile);
+    connect(_viewManager, static_cast<void(ViewManager::*)()>(&Konsole::ViewManager::newViewRequest), this, &Konsole::MainWindow::newTab);
+    connect(_viewManager, &Konsole::ViewManager::viewDetached, this, &Konsole::MainWindow::viewDetached);
 
     // create the main widget
     setupMainWidget();
@@ -145,7 +128,19 @@ MainWindow::MainWindow()
 
     // this must come at the end
     applyKonsoleSettings();
-    connect(KonsoleSettings::self(), SIGNAL(configChanged()), this, SLOT(applyKonsoleSettings()));
+    connect(KonsoleSettings::self(), &Konsole::KonsoleSettings::configChanged, this, &Konsole::MainWindow::applyKonsoleSettings);
+}
+
+void MainWindow::updateUseTransparency()
+{
+    const KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
+
+    bool useTranslucency = KWindowSystem::compositingActive() && args->isSet("transparency");
+
+    setAttribute(Qt::WA_TranslucentBackground, useTranslucency);
+    setAttribute(Qt::WA_NoSystemBackground, false);
+
+    WindowSystemInfo::HAVE_TRANSPARENCY = useTranslucency;
 }
 
 void MainWindow::rememberMenuAccelerators()
@@ -167,9 +162,7 @@ void MainWindow::rememberMenuAccelerators()
 void MainWindow::removeMenuAccelerators()
 {
     foreach(QAction* menuItem, menuBar()->actions()) {
-        QString itemText = menuItem->text();
-        itemText = KGlobal::locale()->removeAcceleratorMarker(itemText);
-        menuItem->setText(itemText);
+        menuItem->setText(menuItem->text().replace('&', QString()));
     }
 }
 
@@ -186,7 +179,7 @@ void MainWindow::correctStandardShortcuts()
     // replace F1 shortcut for help contents
     QAction* helpAction = actionCollection()->action("help_contents");
     if (helpAction) {
-        helpAction->setShortcut(QKeySequence());
+        actionCollection()->setDefaultShortcut(helpAction, QKeySequence());
     }
 
     // replace Ctrl+B shortcut for bookmarks only if user hasn't already
@@ -194,7 +187,7 @@ void MainWindow::correctStandardShortcuts()
     // this will still get changed to Ctrl+Shift+B
     QAction* bookmarkAction = actionCollection()->action("add_bookmark");
     if (bookmarkAction && bookmarkAction->shortcut() == QKeySequence(Qt::CTRL + Qt::Key_B)) {
-        bookmarkAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_B));
+        actionCollection()->setDefaultShortcut(bookmarkAction, Qt::CTRL + Qt::SHIFT + Qt::Key_B);
     }
 }
 
@@ -205,10 +198,10 @@ ViewManager* MainWindow::viewManager() const
 
 void MainWindow::disconnectController(SessionController* controller)
 {
-    disconnect(controller, SIGNAL(titleChanged(ViewProperties*)),
-               this, SLOT(activeViewTitleChanged(ViewProperties*)));
-    disconnect(controller, SIGNAL(rawTitleChanged()),
-               this, SLOT(updateWindowCaption()));
+    disconnect(controller, &Konsole::SessionController::titleChanged,
+               this, &Konsole::MainWindow::activeViewTitleChanged);
+    disconnect(controller, &Konsole::SessionController::rawTitleChanged,
+               this, &Konsole::MainWindow::updateWindowCaption);
 
     // KXmlGuiFactory::removeClient() will try to access actions associated
     // with the controller internally, which may not be valid after the controller
@@ -224,9 +217,8 @@ void MainWindow::activeViewChanged(SessionController* controller)
 {
     // associate bookmark menu with current session
     bookmarkHandler()->setActiveView(controller);
-    disconnect(bookmarkHandler(), SIGNAL(openUrl(KUrl)), 0, 0);
-    connect(bookmarkHandler(), SIGNAL(openUrl(KUrl)), controller,
-            SLOT(openUrl(KUrl)));
+    disconnect(bookmarkHandler(), &Konsole::BookmarkHandler::openUrl, 0, 0);
+    connect(bookmarkHandler(), &Konsole::BookmarkHandler::openUrl, controller, &Konsole::SessionController::openUrl);
 
     if (_pluggedController)
         disconnectController(_pluggedController);
@@ -235,16 +227,11 @@ void MainWindow::activeViewChanged(SessionController* controller)
     _pluggedController = controller;
 
     // listen for title changes from the current session
-    connect(controller, SIGNAL(titleChanged(ViewProperties*)),
-            this, SLOT(activeViewTitleChanged(ViewProperties*)));
-    connect(controller, SIGNAL(rawTitleChanged()),
-            this, SLOT(updateWindowCaption()));
+    connect(controller, &Konsole::SessionController::titleChanged, this, &Konsole::MainWindow::activeViewTitleChanged);
+    connect(controller, &Konsole::SessionController::rawTitleChanged, this, &Konsole::MainWindow::updateWindowCaption);
 
     controller->setShowMenuAction(_toggleMenuBarAction);
-
-    const bool isMenuBarVisible = menuBar()->isVisible();
     guiFactory()->addClient(controller);
-    menuBar()->setVisible(isMenuBarVisible);
 
     // set the current session's search bar
     controller->setSearchBar(searchBar());
@@ -299,49 +286,50 @@ IncrementalSearchBar* MainWindow::searchBar() const
 void MainWindow::setupActions()
 {
     KActionCollection* collection = actionCollection();
-    KAction* menuAction = 0;
+    QAction* menuAction = 0;
 
     // File Menu
-    _newTabMenuAction = new KActionMenu(KIcon("tab-new"), i18nc("@action:inmenu", "&New Tab"), collection);
-    _newTabMenuAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_T));
-    _newTabMenuAction->setShortcutConfigurable(true);
+    _newTabMenuAction = new KActionMenu(QIcon::fromTheme(QStringLiteral("tab-new")), i18nc("@action:inmenu", "&New Tab"), collection);
+    collection->setDefaultShortcut(_newTabMenuAction, Qt::CTRL + Qt::SHIFT + Qt::Key_T);
+    collection->setShortcutsConfigurable(_newTabMenuAction, true);
     _newTabMenuAction->setAutoRepeat(false);
-    connect(_newTabMenuAction, SIGNAL(triggered()), this, SLOT(newTab()));
+    connect(_newTabMenuAction, &KActionMenu::triggered, this, &Konsole::MainWindow::newTab);
     collection->addAction("new-tab", _newTabMenuAction);
+    collection->setShortcutsConfigurable(_newTabMenuAction, true);
 
     menuAction = collection->addAction("clone-tab");
-    menuAction->setIcon(KIcon("tab-duplicate"));
+    menuAction->setIcon(QIcon::fromTheme(QStringLiteral("tab-duplicate")));
     menuAction->setText(i18nc("@action:inmenu", "&Clone Tab"));
-    menuAction->setShortcut(QKeySequence());
+    collection->setDefaultShortcut(menuAction, QKeySequence());
     menuAction->setAutoRepeat(false);
-    connect(menuAction, SIGNAL(triggered()), this, SLOT(cloneTab()));
+    connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::cloneTab);
 
     menuAction = collection->addAction("new-window");
-    menuAction->setIcon(KIcon("window-new"));
+    menuAction->setIcon(QIcon::fromTheme(QStringLiteral("window-new")));
     menuAction->setText(i18nc("@action:inmenu", "New &Window"));
-    menuAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_N));
+    collection->setDefaultShortcut(menuAction, Qt::CTRL + Qt::SHIFT + Qt::Key_N);
     menuAction->setAutoRepeat(false);
-    connect(menuAction, SIGNAL(triggered()), this, SLOT(newWindow()));
+    connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::newWindow);
 
     menuAction = collection->addAction("close-window");
-    menuAction->setIcon(KIcon("window-close"));
+    menuAction->setIcon(QIcon::fromTheme(QStringLiteral("window-close")));
     menuAction->setText(i18nc("@action:inmenu", "Close Window"));
-    menuAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Q));
-    connect(menuAction, SIGNAL(triggered()), this, SLOT(close()));
+    collection->setDefaultShortcut(menuAction, Qt::CTRL + Qt::SHIFT + Qt::Key_Q);
+    connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::close);
 
     // Bookmark Menu
     KActionMenu* bookmarkMenu = new KActionMenu(i18nc("@title:menu", "&Bookmarks"), collection);
     _bookmarkHandler = new BookmarkHandler(collection, bookmarkMenu->menu(), true, this);
     collection->addAction("bookmark", bookmarkMenu);
-    connect(_bookmarkHandler, SIGNAL(openUrls(QList<KUrl>)), this, SLOT(openUrls(QList<KUrl>)));
+    connect(_bookmarkHandler, &Konsole::BookmarkHandler::openUrls, this, &Konsole::MainWindow::openUrls);
 
     // Settings Menu
     _toggleMenuBarAction = KStandardAction::showMenubar(menuBar(), SLOT(setVisible(bool)), collection);
-    _toggleMenuBarAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_M));
+    collection->setDefaultShortcut(_toggleMenuBarAction, Qt::CTRL + Qt::SHIFT + Qt::Key_M);
 
     // Full Screen
     menuAction = KStandardAction::fullScreen(this, SLOT(viewFullScreen(bool)), this, collection);
-    menuAction->setShortcut(QKeySequence(Qt::Key_F11));
+    collection->setDefaultShortcut(menuAction, Qt::Key_F11);
 
     KStandardAction::configureNotifications(this, SLOT(configureNotifications()), collection);
     KStandardAction::keyBindings(this, SLOT(showShortcutsDialog()), collection);
@@ -349,14 +337,14 @@ void MainWindow::setupActions()
 
     menuAction = collection->addAction("manage-profiles");
     menuAction->setText(i18nc("@action:inmenu", "Manage Profiles..."));
-    menuAction->setIcon(KIcon("configure"));
-    connect(menuAction, SIGNAL(triggered()), this, SLOT(showManageProfilesDialog()));
+    menuAction->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
+    connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::showManageProfilesDialog);
 
     // Set up an shortcut-only action for activating menu bar.
     menuAction = collection->addAction("activate-menu");
     menuAction->setText(i18nc("@item", "Activate Menu"));
-    menuAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F10));
-    connect(menuAction, SIGNAL(triggered()), this, SLOT(activateMenuBar()));
+    collection->setDefaultShortcut(menuAction, Qt::CTRL + Qt::SHIFT + Qt::Key_F10);
+    connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::activateMenuBar);
 }
 
 void MainWindow::viewFullScreen(bool fullScreen)
@@ -376,11 +364,9 @@ void MainWindow::setProfileList(ProfileList* list)
 {
     profileListChanged(list->actions());
 
-    connect(list, SIGNAL(profileSelected(Profile::Ptr)), this,
-            SLOT(newFromProfile(Profile::Ptr)));
+    connect(list, &Konsole::ProfileList::profileSelected, this, &Konsole::MainWindow::newFromProfile);
 
-    connect(list, SIGNAL(actionsChanged(QList<QAction*>)), this,
-            SLOT(profileListChanged(QList<QAction*>)));
+    connect(list, &Konsole::ProfileList::actionsChanged, this, &Konsole::MainWindow::profileListChanged);
 }
 
 void MainWindow::profileListChanged(const QList<QAction*>& sessionActions)
@@ -389,31 +375,38 @@ void MainWindow::profileListChanged(const QList<QAction*>& sessionActions)
     // it if it is the non-default profile.
     if (sessionActions.size() > 2) {
         // Update the 'New Tab' KActionMenu
-        KMenu* newTabMenu = _newTabMenuAction->menu();
-        newTabMenu->clear();
+        if (_newTabMenuAction->menu()) {
+            _newTabMenuAction->menu()->clear();
+        } else {
+            _newTabMenuAction->setMenu(new QMenu());
+        }
         foreach(QAction* sessionAction, sessionActions) {
-            newTabMenu->addAction(sessionAction);
+            _newTabMenuAction->menu()->addAction(sessionAction);
 
             // NOTE: defaultProfile seems to not work here, sigh.
             Profile::Ptr profile = ProfileManager::instance()->defaultProfile();
             if (profile && profile->name() == sessionAction->text().remove('&')) {
-                sessionAction->setIcon(KIcon(profile->icon(), 0, QStringList("emblem-favorite")));
-                newTabMenu->setDefaultAction(sessionAction);
+                QIcon icon(KIconLoader::global()->loadIcon(profile->icon(), KIconLoader::Small, 0, KIconLoader::DefaultState, QStringList("emblem-favorite")));
+                sessionAction->setIcon(icon);
+                _newTabMenuAction->menu()->setDefaultAction(sessionAction);
                 QFont actionFont = sessionAction->font();
                 actionFont.setBold(true);
                 sessionAction->setFont(actionFont);
             }
         }
     } else {
-        KMenu* newTabMenu = _newTabMenuAction->menu();
-        newTabMenu->clear();
+        if (_newTabMenuAction->menu()) {
+            _newTabMenuAction->menu()->clear();
+        } else {
+           _newTabMenuAction->setMenu(new QMenu());
+        }
         Profile::Ptr profile = ProfileManager::instance()->defaultProfile();
 
         // NOTE: Compare names w/o any '&'
         if (sessionActions.size() == 2 &&  sessionActions[1]->text().remove('&') != profile->name()) {
-            newTabMenu->addAction(sessionActions[1]);
+            _newTabMenuAction->menu()->addAction(sessionActions[1]);
         } else {
-            delete newTabMenu;
+            _newTabMenuAction->menu()->deleteLater();
         }
     }
 }
@@ -432,15 +425,15 @@ QString MainWindow::activeSessionDir() const
     }
 }
 
-void MainWindow::openUrls(const QList<KUrl>& urls)
+void MainWindow::openUrls(const QList<QUrl>& urls)
 {
     Profile::Ptr defaultProfile = ProfileManager::instance()->defaultProfile();
 
-    foreach(const KUrl& url, urls) {
+    Q_FOREACH (auto url, urls) {
         if (url.isLocalFile())
             createSession(defaultProfile, url.path());
 
-        else if (url.protocol() == "ssh")
+        else if (url.scheme() == "ssh")
             createSSHSession(defaultProfile, url);
     }
 }
@@ -487,7 +480,7 @@ Session* MainWindow::createSession(Profile::Ptr profile, const QString& director
     return session;
 }
 
-Session* MainWindow::createSSHSession(Profile::Ptr profile, const KUrl& url)
+Session* MainWindow::createSSHSession(Profile::Ptr profile, const QUrl& url)
 {
     if (!profile)
         profile = ProfileManager::instance()->defaultProfile();
@@ -498,10 +491,10 @@ Session* MainWindow::createSSHSession(Profile::Ptr profile, const KUrl& url)
     if (url.port() > -1) {
         sshCommand += QString("-p %1 ").arg(url.port());
     }
-    if (url.hasUser()) {
-        sshCommand += (url.user() + '@');
+    if (!url.userName().isEmpty()) {
+        sshCommand += (url.userName() + '@');
     }
-    if (url.hasHost()) {
+    if (!url.host().isEmpty()) {
         sshCommand += url.host();
     }
 
@@ -623,13 +616,13 @@ void MainWindow::readGlobalProperties(KConfig* config)
 
 void MainWindow::syncActiveShortcuts(KActionCollection* dest, const KActionCollection* source)
 {
-    foreach(QAction * qAction, source->actions()) {
-        if (KAction* kAction = qobject_cast<KAction*>(qAction)) {
-            if (KAction* destKAction = qobject_cast<KAction*>(dest->action(kAction->objectName())))
-                destKAction->setShortcut(kAction->shortcut(KAction::ActiveShortcut), KAction::ActiveShortcut);
+    for (QAction *qAction : source->actions()) {
+        if (QAction *destQAction = dest->action(qAction->objectName())) {
+            destQAction->setShortcut(qAction->shortcut());
         }
     }
 }
+
 void MainWindow::showShortcutsDialog()
 {
     KShortcutsDialog dialog(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsDisallowed, this);
@@ -736,7 +729,7 @@ void MainWindow::setNavigationBehavior(int behavior)
     _viewManager->setNavigationBehavior(behavior);
 }
 
-void MainWindow::setNavigationStyleSheetFromFile(const KUrl& styleSheetFile)
+void MainWindow::setNavigationStyleSheetFromFile(const QUrl& styleSheetFile)
 {
     // Let's only deal w/ local files for now
     if (!styleSheetFile.isLocalFile()) {
@@ -832,5 +825,3 @@ bool MainWindow::focusNextPrevChild(bool)
     return false;
 }
 
-#include "MainWindow.moc"
-
