@@ -22,15 +22,15 @@
 
 // Qt
 #include <QtCore/QPointer>
+#include <QtCore/QUrl>
 
 // KDE
 #include <KXmlGuiWindow>
-#include <KUrl>
 
 // Konsole
 #include "Profile.h"
 
-class KAction;
+class QAction;
 class KActionMenu;
 class KToggleAction;
 
@@ -86,7 +86,7 @@ public:
      * @param profile The profile to use to create the new session.
      * @param url the URL representing the new SSH connection
      */
-    Session* createSSHSession(Profile::Ptr profile, const KUrl& url);
+    Session* createSSHSession(Profile::Ptr profile, const QUrl& url);
 
     /**
      * create view for the specified session
@@ -106,7 +106,7 @@ public:
     void setNavigationVisibility(int visibility);
     void setNavigationPosition(int position);
     void setNavigationStyleSheet(const QString& stylesheet);
-    void setNavigationStyleSheetFromFile(const KUrl& stylesheetfile);
+    void setNavigationStyleSheetFromFile(const QUrl& stylesheetfile);
     void setNavigationBehavior(int behavior);
     void setShowQuickButtons(bool show);
 
@@ -162,14 +162,15 @@ private slots:
 
     void updateWindowIcon();
     void updateWindowCaption();
-
-    void openUrls(const QList<KUrl>& urls);
+    void openUrls(const QList<QUrl>& urls);
 
     // Sets the list of profiles to be displayed under the "New Tab" action
     void setProfileList(ProfileList* list);
 
     void applyKonsoleSettings();
 
+    void updateUseTransparency();
+
 public slots:
     void viewFullScreen(bool fullScreen);
 
@@ -196,7 +197,7 @@ private:
     BookmarkHandler* bookmarkHandler() const;
 
     // sets the active shortcuts of actions in 'dest' to the shortcuts of actions
-    // with the same name in 'source' (see KAction::ActiveShortcut)
+    // with the same name in 'source' (see QAction::ActiveShortcut)
     static void syncActiveShortcuts(KActionCollection* dest, const KActionCollection* source);
 
 private:
